@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -100,10 +96,6 @@ public class FormatData_es_419 extends ListResourceBundle {
                "3.\u00ba trimestre",
                "4.\u00ba trimestre",
             };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "a.m.",
-               "p.m.",
-            };
         final String[] metaValue_TimePatterns = new String[] {
                "HH:mm:ss zzzz",
                "HH:mm:ss z",
@@ -138,84 +130,36 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "S",
                 }
             },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "hora est\u00e1ndar de {0}" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} 'a' 'las' {0}",
-                    "{1} 'a' 'las' {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
-            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "latn.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                    "",
-                    "",
-                }
-            },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "a.m./p.m." },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "islamic.MonthNames",
-                new String[] {
-                    "Muharram",
-                    "Safar",
-                    "Rabi\u02bb I",
-                    "Rabi\u02bb II",
-                    "Jumada I",
-                    "Jumada II",
-                    "Rajab",
-                    "Sha\u02bbban",
-                    "Ramadan",
-                    "Shawwal",
-                    "Dhu\u02bbl-Qi\u02bbdah",
-                    "Dhu\u02bbl-Hijjah",
-                    "",
-                }
-            },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "roc.DayNarrows", metaValue_DayNarrows },
+            { "standalone.DayAbbreviations",
+                new String[] {
+                    "dom.",
+                    "lun.",
+                    "mar.",
+                    "mi\u00e9.",
+                    "jue.",
+                    "vie.",
+                    "s\u00e1b.",
+                }
+            },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -237,6 +181,7 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "timezone.regionFormat.daylight", "hora de verano de {0}" },
             { "DatePatterns",
                 new String[] {
@@ -246,9 +191,37 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "d/M/yy",
                 }
             },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
+            { "latn.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "islamic.MonthAbbreviations",
                 new String[] {
@@ -301,7 +274,24 @@ public class FormatData_es_419 extends ListResourceBundle {
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterNames },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "islamic.MonthNames",
+                new String[] {
+                    "Muharram",
+                    "Safar",
+                    "Rabi\u02bb I",
+                    "Rabi\u02bb II",
+                    "Jumada I",
+                    "Jumada II",
+                    "Rajab",
+                    "Sha\u02bbban",
+                    "Ramadan",
+                    "Shawwal",
+                    "Dhu\u02bbl-Qi\u02bbdah",
+                    "Dhu\u02bbl-Hijjah",
+                    "",
+                }
+            },
         };
         return data;
     }
