@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -91,15 +87,25 @@ public class FormatData_es_MX extends ListResourceBundle {
                "3T",
                "4T",
             };
-        final String[] metaValue_AmPmMarkers = new String[] {
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "a.\u00a0m.",
                "p.\u00a0m.",
+               "",
+               "del mediod\u00eda",
+               "de la madrugada",
+               "ma\u00f1ana",
+               "",
+               "",
+               "de la tarde",
+               "",
+               "de la noche",
+               "",
             };
         final String[] metaValue_TimePatterns = new String[] {
-               "H:mm:ss zzzz",
-               "H:mm:ss z",
-               "H:mm:ss",
-               "H:mm",
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d 'de' MMMM 'de' y G",
@@ -115,9 +121,6 @@ public class FormatData_es_MX extends ListResourceBundle {
             };
         final Object[][] data = new Object[][] {
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "TimePatterns", metaValue_TimePatterns },
@@ -125,18 +128,15 @@ public class FormatData_es_MX extends ListResourceBundle {
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "DayNarrows", metaValue_DayNarrows },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -163,12 +163,13 @@ public class FormatData_es_MX extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "DateTimePatterns",
                 new String[] {
-                    "{1} 'a' 'las' {0}",
-                    "{1} 'a' 'las' {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
                     "{1} {0}",
                     "{1} {0}",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -187,8 +188,8 @@ public class FormatData_es_MX extends ListResourceBundle {
                 }
             },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -217,14 +218,13 @@ public class FormatData_es_MX extends ListResourceBundle {
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "QuarterAbbreviations", metaValue_QuarterNames },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
     }
