@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -374,6 +370,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur Moskov",
                "",
             };
+        final String[] Ponape = new String[] {
+               "eur Pohnpei",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Tahiti = new String[] {
                "eur Tahiti",
                "",
@@ -726,12 +730,12 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "eur Enez Macquarie",
-               "",
-               "",
+        final String[] Lord_Howe = new String[] {
+               "eur c\u02bchoa\u00f1v Lord Howe",
                "",
+               "eur ha\u00f1v Lord Howe",
                "",
+               "eur Lord Howe",
                "",
             };
         final String[] Marquesas = new String[] {
@@ -998,6 +1002,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur Europa ar C\u02bchorn\u00f4g",
                "",
             };
+        final String[] Mexico_Pacific = new String[] {
+               "eur c\u02bchoa\u00f1v an Habask mec\u02bchikan",
+               "",
+               "eur ha\u00f1v an Habask mec\u02bchikan",
+               "",
+               "eur an Habask mec\u02bchikan",
+               "",
+            };
         final String[] Africa_Southern = new String[] {
                "eur c\u02bchoa\u00f1v Suafrika",
                "",
@@ -1046,6 +1058,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Hawaii_Aleutian = new String[] {
+               "eur c\u02bchoa\u00f1v Hawaii hag an Aleouted",
+               "",
+               "eur ha\u00f1v Hawaii hag an Aleouted",
+               "",
+               "eur Hawaii hag an Aleouted",
+               "",
+            };
         final String[] Phoenix_Islands = new String[] {
                "eur Inizi Phoenix",
                "",
@@ -1189,6 +1209,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
+            { "Pacific/Honolulu", Hawaii_Aleutian },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -1243,7 +1264,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1272,6 +1293,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Africa/Dakar", GMT },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
+            { "America/Adak", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1378,6 +1400,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1390,7 +1413,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1432,6 +1455,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
+            { "Pacific/Ponape", Ponape },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
             { "Pacific/Tarawa", Gilbert_Islands },
@@ -1503,6 +1527,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
@@ -1512,7 +1537,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1539,6 +1563,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Indian/Mauritius", Mauritius },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
+            { "Pacific/Johnston", Hawaii_Aleutian },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1547,6 +1572,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
+            { "America/Chihuahua", Mexico_Pacific },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1581,6 +1607,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
             { "America/Guadeloupe", Atlantic },
+            { "America/Hermosillo", Mexico_Pacific },
             { "America/Kralendijk", Atlantic },
             { "America/Louisville", America_Eastern },
             { "America/Martinique", Atlantic },
@@ -1589,7 +1616,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1615,6 +1642,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
             { "Atlantic/Cape_Verde", Cape_Verde },
+            { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
@@ -1628,7 +1656,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
