@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -129,7 +125,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
         final String[] Iran = new String[] {
                "Tamdanang Oras sa Iran",
                "",
-               "Oras sa Adlawan sa Iran",
+               "Oras sa Tag-init sa Iran",
                "",
                "Oras sa Iran",
                "",
@@ -183,11 +179,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
                "",
             };
         final String[] China = new String[] {
-               "Tamdanang Oras sa China",
+               "Tamdanang Oras sa Tsina",
                "",
-               "Oras sa Adlawan sa China",
+               "Oras sa Tag-init sa Tsina",
                "",
-               "Oras sa China",
+               "Oras sa Tsina",
                "",
             };
         final String[] Cocos = new String[] {
@@ -225,7 +221,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
         final String[] Korea = new String[] {
                "Tamdanang Oras sa Korea",
                "",
-               "Oras sa Adlawan sa Korea",
+               "Oras sa Tag-init sa Korea",
                "",
                "Oras sa Korea",
                "",
@@ -337,7 +333,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
         final String[] Israel = new String[] {
                "Tamdanang Oras sa Israel",
                "",
-               "Oras sa Adlawan sa Israel",
+               "Oras sa Tag-init sa Israel",
                "",
                "Oras sa Israel",
                "",
@@ -385,7 +381,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
         final String[] Taipei = new String[] {
                "Tamdanang Oras sa Taipei",
                "",
-               "Oras sa Adlawan sa Taipei",
+               "Oras sa Tag-init sa Taipei",
                "",
                "Oras sa Taipei",
                "",
@@ -417,7 +413,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
         final String[] Arabian = new String[] {
                "Tamdanang Oras sa Arabia",
                "",
-               "Oras sa Adlawan sa Arabia",
+               "Oras sa Tag-init sa Arabia",
                "",
                "Oras sa Arabia",
                "",
@@ -734,14 +730,6 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
                "Oras sa Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Oras sa Macquarie Island",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Oras sa Marquesas",
                "",
@@ -1268,7 +1256,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1416,7 +1404,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1540,7 +1528,6 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1620,7 +1607,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1660,7 +1647,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1690,6 +1677,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Asia/Saigon", "Siyudad sa Ho Chi Minh" },
             { "timezone.excity.Etc/Unknown", "Wala Mailhing Lungsod" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
