@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -151,11 +147,11 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Omsk = new String[] {
-               "Omsk-Normalzeit",
+               "Omsker Normalzeit",
                "",
-               "Omsk-Sommerzeit",
+               "Omsker Sommerzeit",
                "",
-               "Omsk-Zeit",
+               "Omsker Zeit",
                "",
             };
         final String[] Peru = new String[] {
@@ -182,6 +178,14 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Casey-Zeit",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Chilenische Normalzeit",
                "",
@@ -215,7 +219,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] India = new String[] {
-               "Indische Zeit",
+               "Indische Normalzeit",
                "",
                "",
                "",
@@ -535,11 +539,11 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Noronha = new String[] {
-               "Fernando de Noronha-Normalzeit",
+               "Fernando-de-Noronha-Normalzeit",
                "",
-               "Fernando de Noronha-Sommerzeit",
+               "Fernando-de-Noronha-Sommerzeit",
                "",
-               "Fernando de Noronha-Zeit",
+               "Fernando-de-Noronha-Zeit",
                "",
             };
         final String[] Reunion = new String[] {
@@ -591,11 +595,11 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Yakutsk = new String[] {
-               "Jakutsk-Normalzeit",
+               "Jakutsker Normalzeit",
                "",
-               "Jakutsk-Sommerzeit",
+               "Jakutsker Sommerzeit",
                "",
-               "Jakutsk-Zeit",
+               "Jakutsker Zeit",
                "",
             };
         final String[] Atlantic = new String[] {
@@ -766,14 +770,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Lord-Howe-Zeit",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Macquarieinsel-Zeit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Marquesas-Zeit",
                "",
@@ -791,7 +787,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Singapore = new String[] {
-               "Singapur-Zeit",
+               "Singapurische Normalzeit",
                "",
                "",
                "",
@@ -919,7 +915,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Indian_Ocean = new String[] {
-               "Indischer Ozean-Zeit",
+               "Indischer-Ozean-Zeit",
                "",
                "",
                "",
@@ -1079,7 +1075,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] French_Southern = new String[] {
-               "Franz\u00f6sische S\u00fcd- und Antarktisgebiete-Zeit",
+               "Franz\u00f6sische-S\u00fcd-und-Antarktisgebiete-Zeit",
                "",
                "",
                "",
@@ -1300,7 +1296,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1446,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1572,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1653,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1693,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
