@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -119,7 +115,7 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "",
             };
         final String[] ETC_UTC = new String[] {
-               "Hora Universal Coordinada",
+               "hora universal coordinada",
                "",
                "",
                "",
@@ -158,14 +154,6 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
                "hora de las Islas Malvinas",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "hora de la Isla Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Europe_Central = new String[] {
                "hora est\u00e1ndar de Europa central",
                "\u2205\u2205\u2205",
@@ -293,6 +281,7 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
             { "Africa/Tripoli", Europe_Eastern },
+            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast", GMT },
@@ -342,6 +331,7 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
             { "Pacific/Kwajalein", Marshall_Islands },
             { "Pacific/Rarotonga", Cook },
             { "Africa/Ouagadougou", GMT },
+            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -353,12 +343,13 @@ public class TimeZoneNames_es_419 extends TimeZoneNamesBundle {
             { "Pacific/Guadalcanal", Solomon },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
-            { "Antarctica/Macquarie", Macquarie },
             { "America/Cambridge_Bay", America_Mountain },
+            { "timezone.excity.Etc/Unknown", "ciudad desconocida" },
             { "timezone.excity.Pacific/Wake", "Isla Wake" },
             { "timezone.excity.America/Nassau", "Nas\u00e1u" },
             { "timezone.excity.Atlantic/Canary", "Islas Canarias" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
+            { "timezone.excity.Europe/Guernsey", "Guernsey" },
             { "timezone.excity.America/Santiago", "Santiago" },
             { "timezone.excity.America/St_Thomas", "Santo Tom\u00e1s" },
             { "timezone.excity.America/Fort_Nelson", "Fuerte Nelson" },
