@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Am St\u00e1isi\u00fan Casey",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Am Caighde\u00e1nach na Sile",
                "",
@@ -415,7 +419,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Tuvalu = new String[] {
-               "Am Thuvalu",
+               "Am Th\u00faval\u00fa",
                "",
                "",
                "",
@@ -431,7 +435,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Wallis = new String[] {
-               "Am Vail\u00eds agus Fut\u00fana",
+               "Am Wallis agus Futuna",
                "",
                "",
                "",
@@ -559,7 +563,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Solomon = new String[] {
-               "Am Oile\u00e1in Sholom\u00f3n",
+               "Am Oile\u00e1in Sholaimh",
                "",
                "",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "Am Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Am Oile\u00e1n Mhic Guaire",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Am na nOile\u00e1n Marcasach",
                "",
@@ -1047,7 +1043,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Southern = new String[] {
-               "Am Caighde\u00e1nach na hAfraice Theas",
+               "Am na hAfraice Theas",
                "",
                "",
                "",
@@ -1055,19 +1051,19 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Central = new String[] {
-               "Am Caighde\u00e1nach L\u00e1rnach",
+               "Am Caighde\u00e1nach L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh L\u00e1rnach",
+               "Am Samhraidh L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
-               "Am L\u00e1rnach",
+               "Am L\u00e1rnach Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] America_Eastern = new String[] {
-               "Am Caighde\u00e1nach an Oirthir",
+               "Am Caighde\u00e1nach Oirthear Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh an Oirthir",
+               "Am Samhraidh Oirthear Mheirice\u00e1 Thuaidh",
                "",
-               "Am an Oirthir",
+               "Am Oirthear Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] America_Pacific = new String[] {
@@ -1119,11 +1115,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Am Caighde\u00e1nach na Sl\u00e9ibhte",
+               "Am Caighde\u00e1nach Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
-               "Am Samhraidh na Sl\u00e9ibhte",
+               "Am Samhraidh Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
-               "Am na Sl\u00e9ibhte",
+               "Am Sl\u00e9ibhte Mheirice\u00e1 Thuaidh",
                "",
             };
         final String[] Marshall_Islands = new String[] {
@@ -1300,7 +1296,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1446,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1572,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1653,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1693,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1848,7 +1844,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Prague", "Pr\u00e1g" },
             { "timezone.excity.Europe/Samara", "Samara" },
             { "timezone.excity.Europe/Skopje", "Sc\u00f3ip\u00e9" },
-            { "timezone.excity.Europe/Tirane", "Tirane" },
+            { "timezone.excity.Europe/Tirane", "Tior\u00e1na" },
             { "timezone.excity.Europe/Vienna", "V\u00edn" },
             { "timezone.excity.Europe/Warsaw", "V\u00e1rs\u00e1" },
             { "timezone.excity.Europe/Zagreb", "S\u00e1grab" },
