@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u00c0m Chasey",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Bun-\u00e0m na Sile",
                "",
@@ -607,11 +611,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "AT",
             };
         final String[] Brasilia = new String[] {
-               "Bun-\u00e0m Bhrasilia",
+               "Bun-\u00e0m Bhras\u00edlia",
                "",
-               "T\u00ecde samhraidh Bhrasilia",
+               "T\u00ecde samhraidh Bhras\u00edlia",
                "",
-               "\u00c0m Bhrasilia",
+               "\u00c0m Bhras\u00edlia",
                "",
             };
         final String[] Chamorro = new String[] {
@@ -766,14 +770,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u00c0m Eilein MhicGuaire",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u00c0m Eileanan a\u2019 Mharcais",
                "",
@@ -1309,7 +1305,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1468,7 +1464,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1594,7 +1590,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1675,7 +1671,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1715,7 +1711,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1799,7 +1795,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Bahrain", "Bachrain" },
             { "timezone.excity.Asia/Bangkok", "Bangkok" },
             { "timezone.excity.Asia/Barnaul", "Barnaul" },
-            { "timezone.excity.Asia/Bishkek", "Bishkek" },
+            { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Asia/Irkutsk", "Irkutsk" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
@@ -1808,7 +1804,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Magadan", "Magadan" },
             { "timezone.excity.Asia/Nicosia", "Nicosia" },
             { "timezone.excity.Asia/Rangoon", "Rangun" },
-            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
+            { "timezone.excity.Asia/Tbilisi", "T\u2019bilisi" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
             { "timezone.excity.Asia/Yakutsk", "Yakutsk" },
             { "timezone.excity.Asia/Yerevan", "Yerevan" },
@@ -1847,14 +1843,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.Asia/Ashgabat", "A\u015fgabat" },
             { "timezone.excity.Asia/Damascus", "Damascus" },
-            { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
+            { "timezone.excity.Asia/Dushanbe", "Du\u0161anbe" },
             { "timezone.excity.Asia/Jayapura", "Jayapura" },
             { "timezone.excity.Asia/Khandyga", "Khandyga" },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "timezone.excity.Asia/Qostanay", "Qostana\u0131" },
             { "timezone.excity.Asia/Sakhalin", "Sakhalin" },
             { "timezone.excity.Asia/Shanghai", "Shanghai" },
-            { "timezone.excity.Asia/Tashkent", "Tashkent" },
+            { "timezone.excity.Asia/Tashkent", "To\u0161kent" },
             { "timezone.excity.Asia/Ust-Nera", "Ust-Nera" },
             { "timezone.excity.Europe/Athens", "An \u00c0ithne" },
             { "timezone.excity.Europe/Berlin", "Berlin" },
