@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -118,6 +114,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Kabu Verdi",
                "",
             };
+        final String[] Newfoundland = new String[] {
+               "Ora Padron di Tera Nova",
+               "",
+               "Ora di Veron di Tera Nova",
+               "",
+               "Ora di Tera Nova",
+               "",
+            };
         final String[] Africa_Central = new String[] {
                "Ora di \u00c1frika Sentral",
                "",
@@ -166,6 +170,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Europa Osidental",
                "",
             };
+        final String[] Mexico_Pacific = new String[] {
+               "Ora Padron di Pas\u00edfiku Mexikanu",
+               "",
+               "Ora di Veron di Pas\u00edfiku Mexikanu",
+               "",
+               "Ora di Pas\u00edfiku Mexikanu",
+               "",
+            };
         final String[] Africa_Southern = new String[] {
                "Ora di Sul di \u00c1frika",
                "",
@@ -198,6 +210,22 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Pas\u00edfiku",
                "",
             };
+        final String[] Hawaii_Aleutian = new String[] {
+               "Ora Padron di Ava\u00ed i Aleutas",
+               "",
+               "Ora di Veron di Ava\u00ed i Aleutas",
+               "",
+               "Ora di Ava\u00ed i Aleutas",
+               "",
+            };
+        final String[] Pierre_Miquelon = new String[] {
+               "Ora Padron di San Pedru i Mikelon",
+               "",
+               "Ora di Veron di San Pedru i Mikelon",
+               "",
+               "Ora di San Pedru i Mikelon",
+               "",
+            };
         final String[] America_Mountain = new String[] {
                "Ora Padron di Montanha",
                "",
@@ -206,6 +234,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Montanha",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Ora Padron di Noroesti di M\u00e9xiku",
+               "",
+               "Ora di Veron di Noroesti di M\u00e9xiku",
+               "",
+               "Ora di Noroesti di M\u00e9xiku",
+               "",
+            };
         final String[] Australia_Central = new String[] {
                "Ora Padron di Austr\u00e1lia Sentral",
                "",
@@ -230,6 +266,22 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Austr\u00e1lia Osidental",
                "",
             };
+        final String[] Greenland_Eastern = new String[] {
+               "Ora Padron di Gronel\u00e1ndia Oriental",
+               "",
+               "Ora di Veron di Gronel\u00e1ndia Oriental",
+               "",
+               "Ora di Gronel\u00e1ndia Oriental",
+               "",
+            };
+        final String[] Greenland_Western = new String[] {
+               "Ora Padron di Gronel\u00e1ndia Osidental",
+               "",
+               "Ora di Veron di Gronel\u00e1ndia Osidental",
+               "",
+               "Ora di Gronel\u00e1ndia Osidental",
+               "",
+            };
         final String[] Australia_CentralWestern = new String[] {
                "Ora Padron di Austr\u00e1lia Sentru-Osidental",
                "",
@@ -245,9 +297,11 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
+            { "Pacific/Honolulu", Hawaii_Aleutian },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
+            { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
@@ -257,6 +311,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "CAT", Africa_Central },
+            { "CNT", Newfoundland },
             { "CST", America_Central },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
@@ -271,7 +326,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Amman", Europe_Eastern },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -285,6 +340,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "Africa/Dakar", GMT },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
+            { "America/Adak", Hawaii_Aleutian },
             { "America/Nome", Alaska },
             { "Asia/Nicosia", Europe_Eastern },
             { "Europe/Malta", Europe_Central },
@@ -346,6 +402,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "Europe/Zagreb", Europe_Central },
             { "Europe/Zurich", Europe_Central },
             { "Indian/Comoro", Africa_Eastern },
+            { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -356,7 +413,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -394,6 +451,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
+            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
@@ -431,13 +489,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Mazatlan", Mexico_Pacific },
+            { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
             { "America/Shiprock", America_Mountain },
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Troll", GMT },
             { "Atlantic/Bermuda", Atlantic },
             { "Atlantic/Madeira", Europe_Western },
@@ -451,10 +510,12 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
+            { "Pacific/Johnston", Hawaii_Aleutian },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
             { "Africa/Nouakchott", GMT },
             { "Africa/Porto-Novo", Africa_Western },
+            { "America/Chihuahua", Mexico_Pacific },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -474,13 +535,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
             { "America/Guadeloupe", Atlantic },
+            { "America/Hermosillo", Mexico_Pacific },
             { "America/Kralendijk", Atlantic },
             { "America/Louisville", America_Eastern },
             { "America/Martinique", Atlantic },
             { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -509,6 +571,9 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
+            { "America/Santa_Isabel", Mexico_Northwest },
+            { "America/Scoresbysund", Greenland_Eastern },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
@@ -529,14 +594,50 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "Sidadi diskonxedu" },
+            { "timezone.excity.America/Adak", "Adaki" },
+            { "timezone.excity.America/Boise", "Boiz" },
             { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Belize", "Belizi" },
             { "timezone.excity.America/Cancun", "Kankun" },
+            { "timezone.excity.America/Cayman", "Kaiman" },
+            { "timezone.excity.America/Havana", "Avana" },
+            { "timezone.excity.America/Merida", "M\u00e9rida" },
+            { "timezone.excity.America/Panama", "Panam\u00e1" },
             { "timezone.excity.America/Chicago", "Xikagu" },
+            { "timezone.excity.America/Creston", "Kr\u00e9ston" },
+            { "timezone.excity.America/Curacao", "Kurasau" },
+            { "timezone.excity.America/Grenada", "Granada" },
+            { "timezone.excity.America/Jamaica", "Jamaika" },
+            { "timezone.excity.America/Managua", "Man\u00e1gua" },
+            { "timezone.excity.America/Toronto", "Torontu" },
+            { "timezone.excity.America/Anguilla", "Angila" },
+            { "timezone.excity.America/Barbados", "Barbadus" },
+            { "timezone.excity.America/Dominica", "Dominika" },
+            { "timezone.excity.America/Miquelon", "Mikelon" },
+            { "timezone.excity.America/New_York", "Nova Iorki" },
+            { "timezone.excity.America/St_Kitts", "San Kristovan" },
+            { "timezone.excity.America/St_Lucia", "Santa L\u00fasia" },
+            { "timezone.excity.America/Winnipeg", "U\u00ednipeg" },
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
+            { "timezone.excity.America/Anchorage", "Ankoraji" },
             { "timezone.excity.America/Chihuahua", "Xiu\u00e1ua" },
+            { "timezone.excity.America/Guatemala", "Guatimala" },
+            { "timezone.excity.America/Vancouver", "Vankuver" },
             { "timezone.excity.America/Costa_Rica", "Kosta Rika" },
+            { "timezone.excity.America/Guadeloupe", "Guadalupi" },
+            { "timezone.excity.America/Martinique", "Martinika" },
+            { "timezone.excity.America/St_Vincent", "San Bisenti" },
+            { "timezone.excity.America/Mexico_City", "Sidadi di M\u00e9xiku" },
+            { "timezone.excity.America/Puerto_Rico", "Portu Riku" },
             { "timezone.excity.America/Blanc-Sablon", "Blank-Sablon" },
-            { "timezone.excity.America/Indianapolis", "Indianapolis" },
+            { "timezone.excity.America/Indianapolis", "Indian\u00e1polis" },
+            { "timezone.excity.America/Port_of_Spain", "Portu di Spanha" },
+            { "timezone.excity.America/Santo_Domingo", "Santu Dumingu" },
+            { "timezone.excity.America/St_Barthelemy", "San Bartolomeu" },
+            { "timezone.excity.America/Bahia_Banderas", "Ba\u00eda di Banderas" },
+            { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Dakota di Norti" },
+            { "timezone.excity.America/North_Dakota/Center", "Center, Dakota di Norti" },
+            { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota di Norti" },
         };
         return data;
     }
