@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -527,11 +523,11 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
-               "Ora standard Insulelor Norfolk",
+               "Ora standard a Insulei Norfolk",
                "",
-               "Ora de var\u0103 Insulelor Norfolk",
+               "Ora de var\u0103 a Insulei Norfolk",
                "",
-               "Ora Insulelor Norfolk",
+               "Ora Insulei Norfolk",
                "",
             };
         final String[] Noronha = new String[] {
@@ -766,14 +762,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "Ora din Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Ora din Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Ora Insulelor Marchize",
                "",
@@ -1300,7 +1288,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1438,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1564,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1644,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1684,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1951,6 +1938,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
             { "timezone.excity.Atlantic/Azores", "Azore" },
             { "timezone.excity.Atlantic/Canary", "Canare" },
+            { "timezone.excity.Atlantic/Faeroe", "Feroe" },
             { "timezone.excity.Australia/Eucla", "Eucla" },
             { "timezone.excity.Australia/Perth", "Perth" },
             { "timezone.excity.Europe/Belgrade", "Belgrad" },
@@ -2004,7 +1992,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Gibraltar", "Gibraltar" },
             { "timezone.excity.Europe/Ljubljana", "Ljubljana" },
             { "timezone.excity.Europe/Mariehamn", "Mariehamn" },
-            { "timezone.excity.Europe/Podgorica", "Podgorica" },
+            { "timezone.excity.Europe/Podgorica", "Podgori\u021ba" },
             { "timezone.excity.Europe/Stockholm", "Stockholm" },
             { "timezone.excity.Europe/Ulyanovsk", "Ulianovsk" },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
