@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -95,11 +91,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Cuba = new String[] {
-               "Saa za Wastani ya Cuba",
+               "Saa za Wastani ya Kuba",
                "",
-               "Saa za Mchana za Cuba",
+               "Saa za Mchana za Kuba",
                "",
-               "Saa za Cuba",
+               "Saa za Kuba",
                "",
             };
         final String[] Fiji = new String[] {
@@ -207,7 +203,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] India = new String[] {
-               "Saa Wastani za India",
+               "Saa za Wastani za India",
                "",
                "",
                "",
@@ -215,7 +211,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Japan = new String[] {
-               "Saa Wastani za Japan",
+               "Saa za Wastani za Japani",
                "",
                "Saa za Mchana za Japan",
                "",
@@ -471,7 +467,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Ecuador = new String[] {
-               "Saa za Ecuador",
+               "Saa za Ekwado",
                "",
                "",
                "",
@@ -487,11 +483,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Georgia = new String[] {
-               "Saa za Wastani za Georgia",
+               "Saa za Wastani za Jojia",
                "",
-               "Saa za Majira ya joto za Georgia",
+               "Saa za Majira ya joto za Jojia",
                "",
-               "Saa za Georgia",
+               "Saa za Jojia",
                "",
             };
         final String[] Irkutsk = new String[] {
@@ -567,11 +563,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Uruguay = new String[] {
-               "Saa za Wastani za Uruguay",
+               "Saa za Wastani za Urugwai",
                "",
-               "Saa za Majira ya joto za Uruguay",
+               "Saa za Majira ya joto za Urugwai",
                "",
-               "Saa za Uruguay",
+               "Saa za Urugwai",
                "",
             };
         final String[] Vanuatu = new String[] {
@@ -615,11 +611,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Colombia = new String[] {
-               "Saa za Wastani za Colombia",
+               "Saa za Wastani za Kolombia",
                "",
-               "Saa za Majira ya joto za Colombia",
+               "Saa za Majira ya joto za Kolombia",
                "",
-               "Saa za Colombia",
+               "Saa za Kolombia",
                "",
             };
         final String[] Falkland = new String[] {
@@ -663,11 +659,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Paraguay = new String[] {
-               "Saa za Wastani za Paraguay",
+               "Saa za Wastani za Paragwai",
                "",
-               "Saa za Majira ya joto za Paraguay",
+               "Saa za Majira ya joto za Paragwai",
                "",
-               "Saa za Paraguay",
+               "Saa za Paragwai",
                "",
             };
         final String[] Pitcairn = new String[] {
@@ -703,7 +699,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Christmas = new String[] {
-               "Saa za Kisiwa cha Christmas",
+               "Saa za Kisiwa cha Krismasi",
                "",
                "",
                "",
@@ -758,14 +754,6 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "Saa za Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Saa za kisiwa cha Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Saa za Marquesas",
                "",
@@ -775,11 +763,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Mauritius = new String[] {
-               "Saa za Wastani za Mauritius",
+               "Saa za Wastani za Morisi",
                "",
-               "Saa za Majira ya joto za Mauritius",
+               "Saa za Majira ya joto za Morisi",
                "",
-               "Saa za Mauritius",
+               "Saa za Morisi",
                "",
             };
         final String[] Singapore = new String[] {
@@ -1007,7 +995,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Europe_Central = new String[] {
-               "Saa za Wastani za Ulaya ya kati",
+               "Saa za Wastani za Ulaya ya Kati",
                "",
                "Saa za Majira ya joto za Ulaya ya Kati",
                "",
@@ -1031,11 +1019,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Mexico_Pacific = new String[] {
-               "Saa za wastani za pasifiki za Mexico",
+               "Saa za wastani za pasifiki za Meksiko",
                "",
-               "Saa za mchana za pasifiki za Mexico",
+               "Saa za mchana za pasifiki za Meksiko",
                "",
-               "Saa za pasifiki za Mexico",
+               "Saa za pasifiki za Meksiko",
                "",
             };
         final String[] Africa_Southern = new String[] {
@@ -1127,11 +1115,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
             };
         final String[] Mexico_Northwest = new String[] {
-               "Saa za Wastani za Mexico Kaskazini Magharibi",
+               "Saa za Wastani za Meksiko Kaskazini Magharibi",
                "",
-               "Saa za mchana za Mexico Kaskazini Magharibi",
+               "Saa za mchana za Meksiko Kaskazini Magharibi",
                "",
-               "Saa za Mexico Kaskazini Magharibi",
+               "Saa za Meksiko Kaskazini Magharibi",
                "",
             };
         final String[] Papua_New_Guinea = new String[] {
@@ -1292,7 +1280,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1442,7 +1430,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1567,7 +1555,6 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1647,7 +1634,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,7 +1674,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
