@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -174,6 +170,14 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u0643\u0627\u0633\u06d0\u064a \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "\u0686\u0649\u0644\u0649 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -750,14 +754,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u0644\u0648\u0631\u062f-\u062e\u0627\u064a \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u0645\u0627\u0643\u0643\u06c7\u06cb\u0627\u0631\u0649 \u0626\u0627\u0631\u0627\u0644\u0644\u0649\u0631\u0649 \u06cb\u0627\u0642\u062a\u0649",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u0645\u0627\u0631\u0643\u0649\u0632 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -1290,7 +1286,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1439,7 +1435,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1565,7 +1561,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1646,7 +1642,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1686,7 +1682,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
