@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -319,11 +315,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Easter = new String[] {
-               "Easter Island Standard Time",
+               "Aago \u00e0s\u00eck\u00f2 Easter Island",
                "",
-               "Easter Island Summer Time",
+               "Aago Soma Easter Island",
                "",
-               "Easter Island Time",
+               "Aago Ajnde Ib\u00f9gb\u00e9 Omi",
                "",
             };
         final String[] Guyana = new String[] {
@@ -431,7 +427,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Bolivia = new String[] {
-               "Bolivia Time",
+               "Aago Bolivia",
                "",
                "",
                "",
@@ -455,7 +451,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Ecuador = new String[] {
-               "Ecuador Time",
+               "Aago Ecuador",
                "",
                "",
                "",
@@ -511,11 +507,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Noronha = new String[] {
-               "Fernando de Noronha Standard Time",
+               "Aago \u00e0s\u00eck\u00f2 Fenando de Norona",
                "",
-               "Fernando de Noronha Summer Time",
+               "Aago Soma Fernando de Noronha",
                "",
-               "Fernando de Noronha Time",
+               "Aago Fenando de Norona",
                "",
             };
         final String[] Reunion = new String[] {
@@ -553,9 +549,9 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
         final String[] Uruguay = new String[] {
                "Uruguay Standard Time",
                "",
-               "Uruguay Summer Time",
+               "Aago Soma Uruguay",
                "",
-               "Uruguay Time",
+               "Aago Uruguay",
                "",
             };
         final String[] Vanuatu = new String[] {
@@ -583,11 +579,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Brasilia = new String[] {
-               "Brasilia Standard Time",
+               "Aago \u00e0s\u00eck\u00f2 B\u00f9r\u00e0s\u00edl\u00ed\u00e0",
                "",
-               "Brasilia Summer Time",
+               "Aago Soma Brasilia",
                "",
-               "Brasilia Time",
+               "Aago B\u00f9r\u00e0s\u00edl\u00ed\u00e0",
                "",
             };
         final String[] Chamorro = new String[] {
@@ -599,11 +595,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Colombia = new String[] {
-               "Colombia Standard Time",
+               "Aago \u00e0s\u00eck\u00f2 Kolombia",
                "",
-               "Colombia Summer Time",
+               "Aago Soma Colombia",
                "",
-               "Colombia Time",
+               "Aago Kolombia",
                "",
             };
         final String[] Falkland = new String[] {
@@ -679,11 +675,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Argentina = new String[] {
-               "Argentina Standard Time",
+               "Aago \u00e0s\u00eck\u00f2 Argentina",
                "",
-               "Argentina Summer Time",
+               "Aago Soma Argentina",
                "",
-               "Argentina Time",
+               "Aago Aj\u1eb9nt\u00ecn\u00e0",
                "",
             };
         final String[] Christmas = new String[] {
@@ -695,7 +691,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Galapagos = new String[] {
-               "Galapagos Time",
+               "Aago Galapago",
                "",
                "",
                "",
@@ -734,14 +730,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "Lord Howe Time",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Macquarie Island Time",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Marquesas Time",
                "",
@@ -767,7 +755,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Venezuela = new String[] {
-               "Venezuela Time",
+               "Aago Venezuela",
                "",
                "",
                "",
@@ -1268,7 +1256,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1416,7 +1404,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1540,7 +1528,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1620,7 +1607,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1660,7 +1647,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1691,8 +1678,116 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u00ccl\u00fa \u00c0\u00ecm\u1ecd\u0300" },
+            { "timezone.excity.America/Adak", "\u00ecl\u00fa Ad\u00e1k\u00ec" },
+            { "timezone.excity.America/Nome", "\u00ecl\u00fa Nomi" },
+            { "timezone.excity.America/Aruba", "\u00ecl\u00fa Ar\u00fab\u00e1" },
+            { "timezone.excity.America/Boise", "\u00ecl\u00fa B\u1ecd\u0301is\u00e8" },
+            { "timezone.excity.America/Sitka", "\u00ecl\u00fa Sika" },
+            { "timezone.excity.America/Thule", "\u00ecl\u00fa Tul\u00e8" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Belize", "\u00ecl\u00fa B\u1eb9\u0300l\u00ed\u00ecs\u00ec" },
+            { "timezone.excity.America/Cancun", "\u00ecl\u00fa Kancun" },
+            { "timezone.excity.America/Cayman", "il\u00fa Kayman" },
+            { "timezone.excity.America/Dawson", "\u00ecl\u00fa Dawson" },
+            { "timezone.excity.America/Denver", "\u00ecl\u00fa Denver" },
+            { "timezone.excity.America/Havana", "\u00ecl\u00fa Havana" },
+            { "timezone.excity.America/Inuvik", "\u00ecl\u00fa Inuvik" },
+            { "timezone.excity.America/Juneau", "\u00ecl\u00fa Junu" },
+            { "timezone.excity.America/Merida", "\u00ecl\u00fa Merida" },
+            { "timezone.excity.America/Nassau", "\u00ecl\u00fa Nasa\u00f2" },
+            { "timezone.excity.America/Panama", "\u00ecl\u00fa Panama" },
+            { "timezone.excity.America/Regina", "\u00ecl\u00fa Regina" },
+            { "timezone.excity.America/Antigua", "\u00ecl\u00fa Ant\u00edg\u00f9\u00e0" },
+            { "timezone.excity.America/Chicago", "\u00ecl\u00fa Chicago" },
+            { "timezone.excity.America/Creston", "\u00ecl\u00fa K\u00edr\u1eb9st\u1ecd\u0301\u1ecd\u0300n\u00f9" },
+            { "timezone.excity.America/Curacao", "\u00ecl\u00fa Kura\u1e63ao" },
+            { "timezone.excity.America/Detroit", "\u00ecl\u00fa Detroit" },
+            { "timezone.excity.America/Godthab", "\u00ecl\u00fa Nuuk" },
+            { "timezone.excity.America/Grenada", "\u00ecl\u00fa Grenada" },
+            { "timezone.excity.America/Halifax", "\u00ecl\u00fa Halif\u00e1s\u00ec" },
+            { "timezone.excity.America/Iqaluit", "\u00ecl\u00fa Iqaluit" },
+            { "timezone.excity.America/Jamaica", "\u00ecl\u00fa Jamaik\u00e0" },
+            { "timezone.excity.America/Managua", "\u00ecl\u00fa Managua" },
+            { "timezone.excity.America/Marigot", "\u00ecl\u00fa Marig\u1ecd\u0301\u1ecd\u0300t\u00ec" },
+            { "timezone.excity.America/Moncton", "\u00ecl\u00fa Montoni" },
+            { "timezone.excity.America/Nipigon", "\u00ecl\u00fa Nipigoni" },
+            { "timezone.excity.America/Ojinaga", "\u00ecl\u00fa Ojinaga" },
+            { "timezone.excity.America/Phoenix", "\u00ecl\u00fa F\u00edn\u00eds\u00ec" },
+            { "timezone.excity.America/Tijuana", "\u00ecl\u00fa T\u00edj\u00faana" },
+            { "timezone.excity.America/Toronto", "\u00ecl\u00fa Toronto" },
+            { "timezone.excity.America/Tortola", "\u00ecl\u00fa Totola" },
+            { "timezone.excity.America/Yakutat", "\u00ecl\u00fa Yakuta" },
+            { "timezone.excity.America/Anguilla", "\u00ecl\u00fa Ang\u00fa\u00edl\u00e0" },
+            { "timezone.excity.America/Barbados", "\u00ecl\u00fa B\u00e1b\u00e1d\u1ecd\u0301\u1ecd\u0300s\u00ec" },
+            { "timezone.excity.America/Dominica", "\u00ecl\u00fa Dominika" },
+            { "timezone.excity.America/Edmonton", "\u00ecl\u00fa Edmonton" },
+            { "timezone.excity.America/Mazatlan", "\u00ecl\u00fa Masatiani" },
+            { "timezone.excity.America/Miquelon", "\u00ecl\u00fa Mikul\u1ecd\u0301n\u00ec" },
+            { "timezone.excity.America/New_York", "\u00ecl\u00fa New York" },
+            { "timezone.excity.America/Resolute", "\u00ecl\u00fa Resol\u00fat\u00ec" },
+            { "timezone.excity.America/St_Johns", "\u00ecl\u00fa St J\u1ecd\u0301\u1ecd\u0300n\u00f9" },
+            { "timezone.excity.America/St_Kitts", "\u00ecl\u00fa St kitis\u00ec" },
+            { "timezone.excity.America/St_Lucia", "\u00ecl\u00fa St Lusia" },
+            { "timezone.excity.America/Winnipeg", "\u00ecl\u00fa Winipeg\u00ec" },
+            { "timezone.excity.Atlantic/Bermuda", "\u00ecl\u00fa B\u1eb9\u0300m\u00fad\u00e0" },
+            { "timezone.excity.America/Anchorage", "\u00ecl\u00fa Ank\u1ecd\u0301r\u00e9\u00e8j\u00ec" },
+            { "timezone.excity.America/Chihuahua", "\u00ecl\u00fa \u1e62ihuahua" },
+            { "timezone.excity.America/Glace_Bay", "\u00ecl\u00fa omi Glace" },
+            { "timezone.excity.America/Goose_Bay", "\u00ecl\u00fa omi Goos\u00f9" },
+            { "timezone.excity.America/Guatemala", "\u00ecl\u00fa Guatemala" },
+            { "timezone.excity.America/Matamoros", "\u00ecl\u00fa Matamoros\u00ec" },
+            { "timezone.excity.America/Menominee", "\u00ecl\u00fa Menomin\u00ec" },
+            { "timezone.excity.America/Monterrey", "\u00ecl\u00fa Monteri" },
+            { "timezone.excity.America/St_Thomas", "\u00ecl\u00fa St T\u1ecd\u0301m\u00e0s\u00ec" },
+            { "timezone.excity.America/Vancouver", "\u00ecl\u00fa Vankuva" },
+            { "timezone.excity.America/Costa_Rica", "\u00ecl\u00fa Kosta R\u00edk\u00e0" },
+            { "timezone.excity.America/Grand_Turk", "\u00ecl\u00fa Grand Turk" },
+            { "timezone.excity.America/Guadeloupe", "\u00ecl\u00fa Guadeloupe" },
+            { "timezone.excity.America/Hermosillo", "\u00ecl\u00fa Hermosilo" },
+            { "timezone.excity.America/Kralendijk", "\u00ecl\u00fa K\u00edral\u1eb9\u0301nd\u00e1ik\u00ec" },
+            { "timezone.excity.America/Louisville", "\u00ecl\u00fa L\u00fa\u00edf\u00ed\u00ecl\u00ec" },
+            { "timezone.excity.America/Martinique", "\u00ecl\u00fa M\u00e1t\u00edn\u00edk\u00ec" },
+            { "timezone.excity.America/Metlakatla", "\u00ecl\u00fa Metilakatila" },
+            { "timezone.excity.America/Montserrat", "\u00ecl\u00fa Monserat\u00ec" },
+            { "timezone.excity.America/St_Vincent", "\u00ecl\u00fa Finsent\u00ec" },
+            { "timezone.excity.America/Whitehorse", "\u00ecl\u00fa Whitehos\u00ec" },
+            { "timezone.excity.America/El_Salvador", "\u00ecl\u00fa El Savador" },
+            { "timezone.excity.America/Fort_Nelson", "\u00ecl\u00fa Fort Nelson" },
+            { "timezone.excity.America/Los_Angeles", "\u00ecl\u00fa Los Angeles" },
+            { "timezone.excity.America/Mexico_City", "\u00ecl\u00fa M\u1eb9\u0301s\u00edk\u00f2" },
+            { "timezone.excity.America/Pangnirtung", "\u00ecl\u00fa Panituni" },
+            { "timezone.excity.America/Puerto_Rico", "\u00ecl\u00fa Puerto Riko" },
+            { "timezone.excity.America/Rainy_River", "\u00ecl\u00fa Raini Rif\u00e0" },
+            { "timezone.excity.America/Tegucigalpa", "\u00ecl\u00fa Tegusigap\u00e0" },
+            { "timezone.excity.America/Thunder_Bay", "\u00ecl\u00fa Omi Thunder" },
+            { "timezone.excity.America/Yellowknife", "\u00ecl\u00fa Yelon\u00e1f\u00f9" },
+            { "timezone.excity.America/Blanc-Sablon", "\u00ecl\u00fa Blank Sabul\u1ecd\u0301\u1ecd\u0300n\u00ec" },
+            { "timezone.excity.America/Danmarkshavn", "\u00ecl\u00fa Banmarkshan" },
+            { "timezone.excity.America/Dawson_Creek", "\u00ecl\u00fa Dawson Creek" },
+            { "timezone.excity.America/Indiana/Knox", "\u00ecl\u00fa n\u1ecd\u0301s\u00ec" },
+            { "timezone.excity.America/Indianapolis", "\u00ecl\u00fa Indianapolis" },
+            { "timezone.excity.America/Rankin_Inlet", "\u00ecl\u00fa Rankin Inlet" },
+            { "timezone.excity.America/Scoresbysund", "\u00ecl\u00fa Itokotomiti" },
+            { "timezone.excity.America/Cambridge_Bay", "\u00ecl\u00fa \u00f2kun kamb\u00edr\u00ed\u00ecj\u00ec" },
+            { "timezone.excity.America/Coral_Harbour", "\u00ecl\u00fa \u00e0tik\u1ecdk\u00e0n" },
+            { "timezone.excity.America/Indiana/Vevay", "\u00ecl\u00fa Vevay" },
+            { "timezone.excity.America/Lower_Princes", "\u00ecl\u00fa Lower Prince\u2019s Quarter" },
+            { "timezone.excity.America/Port_of_Spain", "\u00ecl\u00fa et\u00ed omi S\u00edp\u00e9\u00e8n\u00ec" },
+            { "timezone.excity.America/Santo_Domingo", "\u00ecl\u00fa Santo Domigo" },
+            { "timezone.excity.America/St_Barthelemy", "\u00ecl\u00fa Batilem\u00ec" },
+            { "timezone.excity.America/Swift_Current", "\u00ecl\u00fa S\u00faf\u00edt\u00f9 K\u1ecd\u0300rent\u00ec" },
+            { "timezone.excity.America/Bahia_Banderas", "\u00ecl\u00fa B\u00e1h\u00ec B\u00e1nd\u1eb9\u0301r\u00e1s\u00ec" },
+            { "timezone.excity.America/Port-au-Prince", "\u00ecl\u00fa Port-au-Prince" },
+            { "timezone.excity.America/Indiana/Marengo", "\u00ecl\u00fa Mar\u1eb9\u0301ngo" },
+            { "timezone.excity.America/Indiana/Winamac", "\u00ecl\u00fa Winamak n\u00ed Indiana" },
+            { "timezone.excity.America/Indiana/Tell_City", "\u00ecl\u00fa Tell City" },
+            { "timezone.excity.America/Indiana/Vincennes", "\u00ecl\u00fa Vincennes n\u00ed Indiana" },
+            { "timezone.excity.America/Indiana/Petersburg", "\u00ecl\u00fa Petersburg" },
+            { "timezone.excity.America/Kentucky/Monticello", "\u00ecl\u00fa Montis\u1eb9\u0301l\u00f2" },
+            { "timezone.excity.America/North_Dakota/Beulah", "\u00ecl\u00fa Beul\u00e0 n\u00ed North Dakota" },
+            { "timezone.excity.America/North_Dakota/Center", "\u00ecl\u00fa Senta North Dakota" },
+            { "timezone.excity.America/North_Dakota/New_Salem", "\u00ecl\u00fa New Salem ni North Dakota" },
         };
         return data;
     }
