@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -102,6 +98,14 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                "\u00c0k\u00f3k\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
                "",
             };
+        final String[] Argentina = new String[] {
+               "Aago \u00e0s\u00eck\u00f2 Argentina",
+               "",
+               "Aago Soma Argentina",
+               "",
+               "Aago Aj\u025bnt\u00ecn\u00e0",
+               "",
+            };
         final String[] Newfoundland = new String[] {
                "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 Newfoundland",
                "",
@@ -274,6 +278,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
+            { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
@@ -294,7 +299,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
@@ -308,6 +313,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "America/Antigua", Atlantic },
+            { "America/Cordoba", Argentina },
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
@@ -317,6 +323,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Jamaica", America_Eastern },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
+            { "America/Mendoza", Argentina },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Ojinaga", America_Mountain },
@@ -359,6 +366,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Pacific/Johnston", Hawaii_Aleutian },
+            { "America/Catamarca", Argentina },
             { "America/Chihuahua", Mexico_Pacific },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -382,7 +390,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "America/El_Salvador", America_Central },
@@ -396,6 +404,7 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Blanc-Sablon", Atlantic },
+            { "America/Buenos_Aires", Argentina },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
@@ -411,16 +420,44 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Swift_Current", America_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Tucuman", Argentina },
+            { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Argentina/La_Rioja", Argentina },
+            { "America/Argentina/San_Juan", Argentina },
+            { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u00ccl\u00fa \u00c0\u00ecm\u0254\u0300" },
+            { "timezone.excity.America/Boise", "\u00ecl\u00fa B\u0254\u0301is\u00e8" },
+            { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
+            { "timezone.excity.America/Belize", "\u00ecl\u00fa B\u025b\u0300l\u00ed\u00ecs\u00ec" },
+            { "timezone.excity.America/Creston", "\u00ecl\u00fa K\u00edr\u025bst\u0254\u0301\u0254\u0300n\u00f9" },
+            { "timezone.excity.America/Curacao", "\u00ecl\u00fa Kurashao" },
+            { "timezone.excity.America/Marigot", "\u00ecl\u00fa Marig\u0254\u0301\u0254\u0300t\u00ec" },
+            { "timezone.excity.America/Barbados", "\u00ecl\u00fa B\u00e1b\u00e1d\u0254\u0301\u0254\u0300s\u00ec" },
+            { "timezone.excity.America/Miquelon", "\u00ecl\u00fa Mikul\u0254\u0301n\u00ec" },
+            { "timezone.excity.America/St_Johns", "\u00ecl\u00fa St J\u0254\u0301\u0254\u0300n\u00f9" },
+            { "timezone.excity.Atlantic/Bermuda", "\u00ecl\u00fa B\u025b\u0300m\u00fad\u00e0" },
+            { "timezone.excity.America/Anchorage", "\u00ecl\u00fa Ank\u0254\u0301r\u00e9\u00e8j\u00ec" },
+            { "timezone.excity.America/Chihuahua", "\u00ecl\u00fa Shihuahua" },
+            { "timezone.excity.America/St_Thomas", "\u00ecl\u00fa St T\u0254\u0301m\u00e0s\u00ec" },
+            { "timezone.excity.America/Kralendijk", "\u00ecl\u00fa K\u00edral\u025b\u0301nd\u00e1ik\u00ec" },
+            { "timezone.excity.America/Mexico_City", "\u00ecl\u00fa M\u025b\u0301s\u00edk\u00f2" },
+            { "timezone.excity.America/Blanc-Sablon", "\u00ecl\u00fa Blank Sabul\u0254\u0301\u0254\u0300n\u00ec" },
+            { "timezone.excity.America/Indiana/Knox", "\u00ecl\u00fa n\u0254\u0301s\u00ec" },
+            { "timezone.excity.America/Coral_Harbour", "\u00ecl\u00fa \u00e0tik\u0254k\u00e0n" },
+            { "timezone.excity.America/Swift_Current", "\u00ecl\u00fa S\u00faf\u00edt\u00f9 K\u0254\u0300rent\u00ec" },
+            { "timezone.excity.America/Bahia_Banderas", "\u00ecl\u00fa B\u00e1h\u00ec B\u00e1nd\u025b\u0301r\u00e1s\u00ec" },
+            { "timezone.excity.America/Indiana/Marengo", "\u00ecl\u00fa Mar\u025b\u0301ngo" },
+            { "timezone.excity.America/Kentucky/Monticello", "\u00ecl\u00fa Montis\u025b\u0301l\u00f2" },
         };
         return data;
     }
