@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u51ef\u897f\u65f6\u95f4",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "\u667a\u5229\u6807\u51c6\u65f6\u95f4",
                "",
@@ -735,7 +739,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
                "",
             };
         final String[] Indochina = new String[] {
-               "\u5370\u5ea6\u652f\u90a3\u65f6\u95f4",
+               "\u4e2d\u5357\u534a\u5c9b\u65f6\u95f4",
                "",
                "",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
                "\u8c6a\u52cb\u7235\u5c9b\u65f6\u95f4",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u9ea6\u5938\u91cc\u5c9b\u65f6\u95f4",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u9a6c\u514b\u8428\u65af\u7fa4\u5c9b\u65f6\u95f4",
                "",
@@ -1300,7 +1296,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1446,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1572,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1653,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1693,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1964,7 +1960,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Belgrade", "\u8d1d\u5c14\u683c\u83b1\u5fb7" },
             { "timezone.excity.Europe/Brussels", "\u5e03\u9c81\u585e\u5c14" },
             { "timezone.excity.Europe/Budapest", "\u5e03\u8fbe\u4f69\u65af" },
-            { "timezone.excity.Europe/Busingen", "\u6bd4\u8f9b\u6839" },
+            { "timezone.excity.Europe/Busingen", "\u5e03\u8f9b\u6839" },
             { "timezone.excity.Europe/Chisinau", "\u57fa\u5e0c\u8bb7\u4e4c" },
             { "timezone.excity.Europe/Guernsey", "\u6839\u897f\u5c9b" },
             { "timezone.excity.Europe/Helsinki", "\u8d6b\u5c14\u8f9b\u57fa" },
