@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -222,22 +218,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Indochina = new String[] {
-               "\u4e2d\u5357\u534a\u5cf6\u6642\u9593",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Macquarie = new String[] {
-               "\u9ea5\u5938\u91cc\u7fa4\u5cf6\u6642\u9593",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u99ac\u514b\u85a9\u65af\u6642\u9593",
                "",
@@ -378,9 +358,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "Asia/Chita", Yakutsk },
             { "Asia/Dubai", Gulf },
             { "Asia/Muscat", Gulf },
-            { "Asia/Saigon", Indochina },
             { "Indian/Mahe", Seychelles },
-            { "Asia/Bangkok", Indochina },
             { "Asia/Colombo", India },
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Tbilisi", Georgia },
@@ -400,7 +378,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
@@ -408,7 +386,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Regina", America_Central },
             { "Asia/Singapore", Singapore },
-            { "Asia/Vientiane", Indochina },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Noumea", New_Caledonia },
             { "America/Creston", America_Mountain },
@@ -421,7 +398,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Ojinaga", America_Mountain },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
-            { "Asia/Phnom_Penh", Indochina },
             { "Indian/Maldives", Maldives },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -448,7 +424,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Grand_Turk", America_Eastern },
             { "America/Louisville", America_Eastern },
             { "America/Paramaribo", Suriname },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Africa/Johannesburg", Africa_Southern },
             { "America/El_Salvador", America_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -463,7 +439,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "Antarctica/Macquarie", Macquarie },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
